=============================
django-flexible-subscriptions
=============================

|PyPI|_ |PythonVersions| |DjangoVersions| |License|_

|BuildStatus|_ |Coverage|_

.. |PyPI| image:: https://img.shields.io/pypi/v/django-flexible-subscriptions.svg
   :alt: PyPI

.. _PyPI: https://pypi.org/project/django-flexible-subscriptions/

.. |PythonVersions| image:: https://img.shields.io/pypi/pyversions/django-flexible-subscriptions.svg
   :alt: PyPI - Python Version

.. |DjangoVersions| image:: https://img.shields.io/pypi/djversions/django-flexible-subscriptions.svg
   :alt: PyPI - Django Version

.. |BuildStatus| image:: https://travis-ci.com/studybuffalo/django-flexible-subscriptions.svg?branch=master
   :alt: Travis-CI build status

.. _BuildStatus: https://travis-ci.com/studybuffalo/django-flexible-subscriptions

.. |Coverage| image:: https://codecov.io/gh/studybuffalo/django-flexible-subscriptions/branch/master/graph/badge.svg
   :alt: Codecov code coverage

.. _Coverage: https://codecov.io/gh/studybuffalo/django-flexible-subscriptions

.. |License| image:: https://img.shields.io/github/license/studybuffalo/django-flexible-subscriptions.svg
   :alt: License

.. _License: https://github.com/studybuffalo/django-flexible-subscriptions/blob/master/LICENSE

Django Flexible Subscriptions provides subscription and recurrent
billing for `Django`_ applications. Any payment provider can be quickly
added by overriding the placeholder methods.

.. _Django: https://www.djangoproject.com/

---------------
Getting Started
---------------

Instructions on installing and configuration can be found on
`Read The Docs`_.

.. _Read The Docs: https://django-flexible-subscriptions.readthedocs.io/en/latest/

-------
Support
-------

The `docs provide examples for setup and common issues`_ to be aware
of. For any other issues, you can submit a `GitHub Issue`_.

.. _docs provide examples for setup and common issues: https://django-flexible-subscriptions.readthedocs.io/en/latest/installation.html

.. _GitHub Issue: https://github.com/studybuffalo/django-flexible-subscriptions/issues

------------
Contributing
------------

Contributions are welcome, especially to address bugs and extend
functionality. Full `details on contributing can be found in the docs`_.

.. _details on contributing can be found in the docs: https://django-flexible-subscriptions.readthedocs.io/en/latest/contributing.html

----------
Versioning
----------

This package uses a MAJOR.MINOR.PATCH versioning, as outlined at
`Semantic Versioning 2.0.0`_.

.. _Semantic Versioning 2.0.0: https://semver.org/

-------
Authors
-------

Joshua Robert Torrance (StudyBuffalo_)

.. _StudyBuffalo: https://github.com/studybuffalo

-------
License
-------

This project is licensed under the GPLv3. Please see the LICENSE_ file for details.

.. _LICENSE: https://github.com/studybuffalo/django-flexible-subscriptions/blob/master/LICENSE

----------------
Acknowledgements
----------------

* `Django Oscar`_ and `Django Subscription`_ for inspiring many of the
  initial design decisions.

.. _Django Oscar: https://github.com/django-oscar/django-oscar
.. _Django Subscription: https://github.com/zhaque/django-subscription

---------
Changelog
---------

You can view all `package changes on the docs`_.

.. _package changes on the docs: https://django-flexible-subscriptions.readthedocs.io/en/latest/changelog.html
